@@ -30,10 +30,10 @@ BrightnessControl::BrightnessControl(QObject *parent)
     // DBus
     new BrightnessControlAdaptor(this);
 
-    connect(core()->backend(),
-            &PowerDevil::BackendInterface::screenBrightnessChanged,
+    connect(core()->screenBrightnessController(),
+            &ScreenBrightnessController::brightnessInfoChanged,
             this,
-            &PowerDevil::BundledActions::BrightnessControl::onBrightnessChangedFromBackend);
+            &PowerDevil::BundledActions::BrightnessControl::onBrightnessChangedFromController);
 
     KActionCollection *actionCollection = new KActionCollection(this);
     actionCollection->setComponentDisplayName(i18nc("Name for powerdevil shortcuts category", "Power Management"));
@@ -71,7 +71,7 @@ void BrightnessControl::onProfileLoad(const QString &previousProfile, const QStr
         // We don't want to change anything here
         qCDebug(POWERDEVIL) << "Not changing brightness, the current one is lower and the profile is more conservative";
     } else if (absoluteBrightnessValue >= 0) {
-        backend()->setScreenBrightness(absoluteBrightnessValue);
+        core()->screenBrightnessController()->setBrightness(absoluteBrightnessValue);
     }
 }
 
@@ -81,7 +81,7 @@ void BrightnessControl::triggerImpl(const QVariantMap & /*args*/)
 
 bool BrightnessControl::isSupported()
 {
-    return backend()->screenBrightnessAvailable();
+    return core()->screenBrightnessController()->isSupported();
 }
 
 bool BrightnessControl::loadAction(const PowerDevil::ProfileSettings &profileSettings)
@@ -94,36 +94,59 @@ bool BrightnessControl::loadAction(const PowerDevil::ProfileSettings &profileSet
     return true;
 }
 
-void BrightnessControl::onBrightnessChangedFromBackend(const BrightnessLogic::BrightnessInfo &info)
+void BrightnessControl::onBrightnessChangedFromController(const BrightnessLogic::BrightnessInfo &info)
 {
-    Q_EMIT brightnessChanged(info.value);
-    Q_EMIT brightnessMaxChanged(info.valueMax);
+    if (info.value != m_lastBrightnessInfo.value) {
+        Q_EMIT brightnessChanged(info.value);
+    }
+    if (info.valueMax != m_lastBrightnessInfo.valueMax) {
+        Q_EMIT brightnessMaxChanged(info.valueMax);
+    }
+    if (info.valueMin != m_lastBrightnessInfo.valueMin) {
+        Q_EMIT brightnessMinChanged(info.valueMin);
+    }
+
+    m_lastBrightnessInfo = info;
 }
 
 int BrightnessControl::brightness() const
 {
-    return backend()->screenBrightness();
+    return core()->screenBrightnessController()->brightness();
 }
 
 int BrightnessControl::brightnessMax() const
 {
-    return backend()->screenBrightnessMax();
+    return core()->screenBrightnessController()->maxBrightness();
+}
+
+int BrightnessControl::brightnessMin() const
+{
+    return core()->screenBrightnessController()->minBrightness();
+}
+
+int BrightnessControl::knownSafeBrightnessMin() const
+{
+    // Theoretically we should provide a change signal for this property, because it can change as
+    // display connections change, even if it's constant per individual display. In practice,
+    // this won't change as long as laptop screens don't get added or removed at runtime.
+    // Which shouldn't happen.
+    return core()->screenBrightnessController()->knownSafeMinBrightness();
 }
 
 void BrightnessControl::setBrightness(int value)
 {
-    backend()->setScreenBrightness(value);
+    core()->screenBrightnessController()->setBrightness(value);
     BrightnessOSDWidget::show(brightnessPercent(value));
 }
 
 void BrightnessControl::setBrightnessSilent(int value)
 {
-    backend()->setScreenBrightness(value);
+    core()->screenBrightnessController()->setBrightness(value);
 }
 
 void BrightnessControl::increaseBrightness()
 {
-    const int newBrightness = backend()->screenBrightnessKeyPressed(BrightnessLogic::Increase);
+    const int newBrightness = core()->screenBrightnessController()->screenBrightnessKeyPressed(BrightnessLogic::Increase);
     if (newBrightness > -1) {
         BrightnessOSDWidget::show(brightnessPercent(newBrightness));
     }
@@ -131,7 +154,7 @@ void BrightnessControl::increaseBrightness()
 
 void BrightnessControl::increaseBrightnessSmall()
 {
-    const int newBrightness = backend()->screenBrightnessKeyPressed(BrightnessLogic::IncreaseSmall);
+    const int newBrightness = core()->screenBrightnessController()->screenBrightnessKeyPressed(BrightnessLogic::IncreaseSmall);
     if (newBrightness > -1) {
         BrightnessOSDWidget::show(brightnessPercent(newBrightness));
     }
@@ -139,7 +162,7 @@ void BrightnessControl::increaseBrightnessSmall()
 
 void BrightnessControl::decreaseBrightness()
 {
-    const int newBrightness = backend()->screenBrightnessKeyPressed(BrightnessLogic::Decrease);
+    const int newBrightness = core()->screenBrightnessController()->screenBrightnessKeyPressed(BrightnessLogic::Decrease);
     if (newBrightness > -1) {
         BrightnessOSDWidget::show(brightnessPercent(newBrightness));
     }
@@ -147,7 +170,7 @@ void BrightnessControl::decreaseBrightness()
 
 void BrightnessControl::decreaseBrightnessSmall()
 {
-    const int newBrightness = backend()->screenBrightnessKeyPressed(BrightnessLogic::DecreaseSmall);
+    const int newBrightness = core()->screenBrightnessController()->screenBrightnessKeyPressed(BrightnessLogic::DecreaseSmall);
     if (newBrightness > -1) {
         BrightnessOSDWidget::show(brightnessPercent(newBrightness));
     }
@@ -155,7 +178,7 @@ void BrightnessControl::decreaseBrightnessSmall()
 
 int BrightnessControl::brightnessSteps() const
 {
-    return backend()->screenBrightnessSteps();
+    return core()->screenBrightnessController()->brightnessSteps();
 }
 
 int BrightnessControl::brightnessPercent(float value) const
