@@ -8,7 +8,6 @@
 
 #include <PowerDevilProfileSettings.h>
 #include <powerdevil_debug.h>
-#include <powerdevilbackendinterface.h>
 #include <powerdevilcore.h>
 
 #include "suspendsessionadaptor.h"
@@ -110,7 +109,7 @@ void SuspendSession::triggerImpl(const QVariantMap &args)
     }
     case PowerDevil::PowerButtonAction::PromptLogoutDialog: {
         SessionManagement sessionManager;
-        sessionManager.requestShutdown(SessionManagement::ConfirmationMode::ForcePrompt);
+        sessionManager.requestLogoutPrompt();
         break;
     }
     case PowerDevil::PowerButtonAction::LockScreen: {
